@@ -12,7 +12,11 @@ dudraw.clear(dudraw.BLACK)
 
 dudraw.set_pen_color(dudraw.WHITE)
 dudraw.set_pen_width(20)
-for i in range(1, 48):
-    dudraw.line(i*10, math.sin(i/5)*50+250, (i+1)*10, math.sin((i+1)/5)*50+250)
+
+points = []
+for i in range(1, 200):
+    points.append((i*2, math.sin(i/5)*50+250))
+    
+dudraw.polyline([p[0] for p in points], [p[1] for p in points])
 
 dudraw.show(Infinity)
\ No newline at end of file
